
# a Translate Tools

## Doc

can use two mode. to auto translation from paste blackboard.
but this only support 
> **pbpaste**

## Server mode:

```sh
    Translate -S
    # will open local's port 8080 ,
    # you can use browser to see it.
```

    will send result to http://localhost:8080/

## mac mode

will use display notification center.

```sh
    Translate -m
```

